import React, { createContext, useState, useContext, useEffect, useCallback } from 'react';
import { fetchFriendsNotification } from '@api/friends';
import { StoreType, storage } from 'src/storage';

const NotificationContext = createContext({
  isNotificationActive: false,
  updateNotificationStatus: () => {}
});

export const NotificationProvider = ({ children }: { children: React.ReactNode }) => {
  const [isNotificationActive, setIsNotificationActive] = useState(
    storage.get('friendsNotification', StoreType.BOOLEAN) as boolean
  );
  const token = storage.get('token', StoreType.STRING) as string;

  const updateNotificationStatus = useCallback(async () => {
    try {
      const data = await fetchFriendsNotification(token);
      const isActive = data && data.active;
      setIsNotificationActive(isActive as boolean);
      storage.set('friendsNotification', isActive as boolean);
    } catch (error) {
      console.error('Failed to fetch notifications', error);
    }
  }, [token]);

  useEffect(() => {
    updateNotificationStatus();
  }, [token]);

  useEffect(() => {
    const interval = setInterval(() => {
      updateNotificationStatus();
    }, 15000);

    return () => clearInterval(interval);
  }, [updateNotificationStatus]);

  return (
    <NotificationContext.Provider value={{ isNotificationActive, updateNotificationStatus }}>
      {children}
    </NotificationContext.Provider>
  );
};

export const useNotification = () => useContext(NotificationContext);
